@@ -111,7 +111,7 @@ $is_root = (defined('AUTH_USER') && AUTH_USER === 'root');
 <script src="js/xterm/addons/xterm-addon-web-links.js"></script>
 
 <script>
-const nonce = '<?php echo $_SESSION['nonce'] ?? ''; ?>';
+const nonce = '<?php echo get_csrf_token(); ?>';
 let terminal = null;
 let fitAddon = null;
 let webLinksAddon = null;
@@ -168,7 +168,7 @@ function loadContainers() {
         method: 'POST',
         headers: {
             'Content-Type': 'application/json',
-            'X-Nonce': nonce
+            'X-CSRF-Token': nonce
         },
         body: JSON.stringify({ action: 'list_containers' })
     })
@@ -206,7 +206,7 @@ async function connectToContainer() {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/json',
-                'X-Nonce': nonce
+                'X-CSRF-Token': nonce
             }
         });
         
